GALINI
======

Contributors
------------

.. list-table::
   :header-rows: 1
   :widths: 10 40 50

   * - GitHub
     - Name
     - Acknowledgements

   * - |fracek|_
     - Francesco Ceccon
     - This work was funded by an Engineering & Physical Sciences Research Council Research Fellowship [GrantNumber EP/P016871/1]

   * - |rb2309|_
     - Radu Baltean-Lugojan
     - This work was funded by an Engineering & Physical Sciences Research Council Research Fellowship [GrantNumber EP/P016871/1]


.. _fracek: https://github.com/fracek
.. |fracek| raw:: html

  <img src="https://avatars1.githubusercontent.com/u/282580?s=120&v=4" width="80px" />

.. _rb2309: https://github.com/rb2309
.. |rb2309| raw:: html

  <img src="https://avatars2.githubusercontent.com/u/1138134?s=120&v=4" width="80px" />


Table of Contents
-----------------

.. toctree::
   :maxdepth: 2

   installation.rst
   commands/index.rst
   branch_and_bound/index.rst
   branch_and_cut/index.rst
   relaxations/index.rst
